pub struct TextItem {
pub position: i32,
pub text: Box<TextComponent>,
}Expand description
TextItem : Rich positional text, usually presented as a collection of bullet points.
Fields
position: i32The rank or index of this text item within the collection. Different items cannot occupy the same position within a single collection.
text: Box<TextComponent>Implementations